@@ -1,6 +1,6 @@
 ##############################################################################
 # JSON::Any
-# v1.07
+# v1.01
 # Copyright (c) 2007 Chris Thompson
 ##############################################################################
 
@@ -10,18 +10,6 @@ use warnings;
 use strict;
 use Carp;
 
-=head1 NAME
-
-JSON::Any - Wrapper Class for the various JSON classes.
-
-=head1 VERSION
-
-Version 1.07
-
-=cut
-
-our $VERSION = '1.06_01';
-
 my ( %conf, $handler, $encoder, $decoder );
 
 BEGIN {
@@ -75,12 +63,12 @@ BEGIN {
                   shrink
                   max_depth
                 );
-
-                my $obj = $handler->new;
+                               
+                my $obj = $handler->new;                
                 for my $mutator (@params) {
                     next unless exists $self->{$mutator};
                     $obj = $obj->$mutator( $self->{$mutator} );
-                }
+                }                
                 $encoder = 'encode';
                 $decoder = 'decode';
                 return $obj;
@@ -102,17 +90,13 @@ sub import {
 
     ( $handler, $encoder, $decoder ) = ();
 
-    if ( $ENV{JSON_ANY_ORDER} ) {
-        next if @order;
-        @order = split /\s/, $ENV{JSON_ANY_ORDER};
-    }
     @order = qw(XS JSON DWIW Syck) unless @order;
 
     foreach my $testmod (@order) {
         $testmod = "JSON::$testmod" unless $testmod eq "JSON";
         eval "require $testmod";
         unless ($@) {
-            $handler = $testmod;
+            $handler = $testmod;            
             ( my $key = lc($handler) ) =~ s/::/_/g;
             $encoder = $conf{$key}->{encoder};
             $decoder = $conf{$key}->{decoder};
@@ -120,11 +104,23 @@ sub import {
         }
     }
 
-    croak "Couldn't find a JSON Package."   unless $handler;
+    croak "Couldn't find a JSON Package." unless $handler;
     croak "Couldn't find a decoder method." unless $decoder;
     croak "Couldn't find a encoder method." unless $encoder;
 }
 
+=head1 NAME
+
+JSON::Any - Wrapper Class for the various JSON classes.
+
+=head1 VERSION
+
+Version 1.01
+
+=cut
+
+our $VERSION = '1.01';
+
 =head1 SYNOPSIS
 
 This module will provide a coherent API to bring together the various JSON
@@ -171,18 +167,15 @@ And loading the first one it finds.
 You may change the order by specifying it on the C<use JSON::Any> line:
 
 	use JSON::Any qw(DWIW Syck XS JSON);
-
+	
 Specifying an order that is missing one of the modules will prevent that module from being used:
 
 	use JSON::Any qw(DWIW XS JSON);
 
-This will check in that order, and will never attempt to load JSON::Syck. This can also be set via
-the $ENV{JSON_ANY_ORDER} environment variable.
+This will check in that order, and will never attempt to load JSON::Syck.
 
 =head1 FUNCTIONS
 
-=over
-
 =item C<new>
 
 Will take any of the parameters for the underlying system and pass them through. 
@@ -190,33 +183,22 @@ However these values don't map between JSON modules, so, from a portability
 standpoint this is really only helpful for those paramters that happen
 to have the same name. This will be addressed in a future release.
 
-=back
-
 =cut
 
 sub new {
     my $class = shift;
-    my $self = bless [], $class;
+    my $self  = bless {@_}, $class;
     ( my $key = lc($handler) ) =~ s/::/_/g;
     if ( my $creator = $conf{$key}->{create_object} ) {
-        my @config = @_;
-        if ( $ENV{JSON_ANY_CONFIG} ) {
-            push @config, map { split /=/, $_ } split /,\s*/,
-              $ENV{JSON_ANY_CONFIG};
-        }
-        $self->[0] = $creator->( {@config} );
+        $self->{obj} = $creator->($self);
     }
     return $self;
 }
 
-=over
-
 =item C<handlerType>
 
 Takes no arguments, returns a string indicating which JSON Module is in use.
 
-=back
-
 =cut
 
 sub handlerType {
@@ -224,51 +206,41 @@ sub handlerType {
     $handler;
 }
 
-=over
-
 =item C<handler>
 
 Takes no arguments, if called on an object returns the internal JSON::* 
 object in use.  Otherwise returns the JSON::* package we are using for 
 class methods.
 
-=back
-
 =cut
 
 sub handler {
     my $self = shift;
     if ( ref $self ) {
-        return $self->[0];
+        return $self->{obj};
     }
     return $handler;
 }
 
-=over
-
 =item C<objToJson>
 
 Takes a single argument, a hashref to be converted into JSON.
 It returns the JSON text in a scalar.
 
-=back
-
 =cut
 
 sub objToJson {
     my $self = shift;
     my $obj  = shift;
     if ( ref $self ) {
-        croak "No $handler Object created!" unless exists $self->[0];
-        my $method = $self->[0]->can($encoder);
+        croak "No $handler Object created!" unless exists $self->{obj};
+        my $method = $self->{obj}->can($encoder);
         croak "$handler can't execute $encoder" unless $method;
-        return $self->[0]->$method($obj);
+        return $self->{obj}->$method($obj);
     }
     return $handler->can($encoder)->($obj);
 }
 
-=over
-
 =item C<to_json>
 
 =item C<Dump>
@@ -278,8 +250,6 @@ sub objToJson {
 Aliases for objToJson, can be used interchangeably, regardless of the 
 underlying JSON module.
 
-=back
-
 =cut
 
 {
@@ -289,31 +259,25 @@ underlying JSON module.
     *encode  = \&objToJson;
 }
 
-=over
-
 =item C<jsonToObj>
 
 Takes a single argument, a string of JSON text to be converted
 back into a hashref.
 
-=back
-
 =cut
 
 sub jsonToObj {
     my $self = shift;
-    my $obj  = shift;
+    my $obj  = shift;    
     if ( ref $self ) {
-        croak "No $handler Object created!" unless exists $self->[0];
-        my $method = $self->[0]->can($decoder);
+        croak "No $handler Object created!" unless exists $self->{obj};
+        my $method = $self->{obj}->can($decoder);
         croak "$handler can't execute $encoder" unless $method;
-        return $self->[0]->$method($obj);
+        return $self->{obj}->$method($obj);
     }
     $handler->can($decoder)->($obj);
 }
 
-=over
-
 =item C<from_json>
 
 =item C<Load>
@@ -323,8 +287,6 @@ sub jsonToObj {
 Aliases for jsonToObj, can be used interchangeably, regardless of the 
 underlying JSON module.
 
-=back
-
 =cut
 
 {
@@ -337,7 +299,6 @@ underlying JSON module.
 =head1 AUTHOR
 
 Chris Thompson, C<< <cthom at cpan.org> >>
-Chris Prather, C<< <perigrin at cpan.org> >>
 
 =head1 BUGS
 
@@ -353,7 +314,9 @@ This module came about after discussions on irc.perl.org about the fact
 that there were now six separate JSON perl modules with different interfaces.
 
 In the spirit of Class::Any, JSON::Any was created with the considerable 
-help of Matt 'mst' Trout.
+help of Chris 'perigrin' Prather, and Matt 'mst' Trout.
+
+JSON::Any 1.01 was written almost entirely by Chris Prather.
 
 San Dimas High School Football Rules!
 
